BranchLinkManager class

Branch SDK adapter used by DeferredLinkManagerImpl.

Constructors

BranchLinkManager()
Returns the singleton Branch link manager.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

Creates a short Branch deep link.
Handles a Branch deferred-link URL.
init({bool useTestKey = false, bool enableLog = false, bool disableTrack = false, DeferredDeepLink? onLinkReceived}) Future<void>
Initializes Branch link handling.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() → void
Validates the Branch SDK integration.

Operators

operator ==(Object other) bool
The equality operator.
inherited