DeferredLinkManagerImpl class

Routes Ensemble deferred-link calls to the configured provider.

Inheritance
  • Object
  • DeferredLinkManager
  • DeferredLinkManagerImpl

Constructors

DeferredLinkManagerImpl()
Returns the singleton deferred-link manager.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

Creates a deferred deep link for the selected provider.
override
Handles an incoming deferred-link URL.
override
init({required DeepLinkProvider provider, Map<String, dynamic>? options, DeferredDeepLink? onLinkReceived}) Future<void>
Initializes the selected deferred deep-link provider.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited